@@ -1,10 +1,6 @@
 import os
-import sys
 
 from django.conf import settings
-from django.core.exceptions import ImproperlyConfigured
-from django.core.files.base import ContentFile
-from django.core.files.storage import FileSystemStorage
 from django.core.management.base import BaseCommand
 
 from ... import settings as default_settings
